@@ -382,6 +382,7 @@ def iconv_configure_flags
   ["iconv", "opt"].each do |target|
     config = preserving_globals { dir_config(target) }
     next unless config.any? && try_link_iconv("--with-#{target}-* flags") { dir_config(target) }
+
     idirs, ldirs = config.map do |dirs|
       Array(dirs).flat_map do |dir|
         dir.split(File::PATH_SEPARATOR)
@@ -711,16 +712,16 @@ else
       else
         class << recipe
           def configure
-            cflags = concat_flags(ENV["CFLAGS"], "-fPIC", "-g")
-            execute("configure",
-              ["env", "CHOST=#{host}", "CFLAGS=#{cflags}", "./configure", "--static", configure_prefix])
-          end
-
-          def compile
-            if /darwin/.match?(host)
-              execute("compile", "make AR=#{host}-libtool")
-            else
-              super
+            env = {}
+            env["CFLAGS"] = concat_flags(ENV["CFLAGS"], "-fPIC", "-g")
+            env["CHOST"] = host
+            execute("configure", ["./configure", "--static", configure_prefix], { env: env })
+            if darwin?
+              # needed as of zlib 1.2.13
+              Dir.chdir(work_path) do
+                makefile = File.read("Makefile").gsub(/^AR=.*$/, "AR=#{host}-libtool")
+                File.open("Makefile", "w") { |m| m.write(makefile) }
+              end
             end
           end
         end
@@ -846,6 +847,11 @@ else
       recipe.configure_options += ["RANLIB=/usr/bin/ranlib", "AR=/usr/bin/ar"]
     end
 
+    if windows?
+      cflags = concat_flags(cflags, "-ULIBXSLT_STATIC", "-DIN_LIBXSLT")
+      cflags = concat_flags(cflags, "-ULIBEXSLT_STATIC", "-DIN_LIBEXSLT")
+    end
+
     recipe.configure_options << if source_dir
       "--config-cache"
     else
@@ -980,6 +986,8 @@ have_func("xmlRelaxNGSetParserStructuredErrors") # introduced in libxml 2.6.24
 have_func("xmlRelaxNGSetValidStructuredErrors") # introduced in libxml 2.6.21
 have_func("xmlSchemaSetValidStructuredErrors") # introduced in libxml 2.6.23
 have_func("xmlSchemaSetParserStructuredErrors") # introduced in libxml 2.6.23
+have_func("rb_gc_location") # introduced in Ruby 2.7
+have_func("rb_category_warning") # introduced in Ruby 3.0
 
 have_func("vasprintf")
 
